Stan Math Library: stan/math/prim/scal/fun/identity_free.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

identity_free.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_FUN_IDENTITY_FREE_HPP
2 #define STAN_MATH_PRIM_SCAL_FUN_IDENTITY_FREE_HPP
3
4 namespace stan {
5
6 namespace math {
7
19 template <typename T>
20 inline
21 T identity_free(const T y) {
22 return y;
23 }
24
25 }
26
27 }
28
29 #endif
stan
Definition: log_sum_exp.hpp:8
stan::math::identity_free
T identity_free(const T y)
Returns the result of applying the inverse of the identity constraint transform to the input...
Definition: identity_free.hpp:21

[ Stan Home Page ] © 2011–2016, Stan Development Team.